@@ -7,6 +7,11 @@ class APIKeyNotFound(NeispyException):
         super().__init__("API키를 찾을수없습니다. 샘플키로 요청합니다.")
 
 
+class ArgumentError(NeispyException):
+    def __init__(self):
+        super().__init__("인자값이 틀립니다.")
+
+
 class HTTPException(NeispyException):
     def __init__(self, code, message):
         super().__init__(f'{code} {message}')
